//
//  MTGCommonBridge.cpp
//  Cocos2dxSample-mobile
//
//  Created by YM on 2018/05/16.
//

#include "MTGCommonBridge.h"
#include "cocos2d.h"

USING_NS_CC;

using namespace cn::mtgsdk;

#if (CC_TARGET_PLATFORM == CC_PLATFORM_ANDROID)

#include "platform/android/jni/JniHelper.h"
#include <jni.h>

const char* AppActivityCalssName3 = "org/cocos2dx/mtgad/MTGCommon";

CommonResultEvent onCommonCallBack;

//JNI调用C++

extern "C" {

JNIEXPORT void JNICALL Java_org_cocos2dx_mtgad_MTGCommon_dispatchStatusEventAsync(JNIEnv *env, jclass, jstring jcode, jstring jlevel) {
    auto tempID = env->GetStringUTFChars(jcode, NULL);
    string codeID = tempID;
    env->ReleaseStringUTFChars(jcode, tempID);

    auto tempID1 = env->GetStringUTFChars(jlevel, NULL);
    string levelID = tempID1;
    env->ReleaseStringUTFChars(jlevel, tempID1);

    onCommonCallBack(codeID,levelID);
}
}

void releaseMethod3(JniMethodInfo &mi) {
    if(mi.classID != NULL)
        mi.env->DeleteLocalRef(mi.classID);
}

//initsdk
void MTGCommonBridge::initMintegralSDK(std::string appid,std::string apikey)
{
    cocos2d::JniMethodInfo mi;
    if (cocos2d::JniHelper::getStaticMethodInfo(mi, AppActivityCalssName3, "initMintegralSDK", "(Ljava/lang/String;Ljava/lang/String;)V")) {
        
        jstring jappid = mi.env->NewStringUTF( appid.c_str() );
        jstring japikey = mi.env->NewStringUTF( apikey.c_str() );
        
        mi.env->CallStaticVoidMethod(mi.classID, mi.methodID,jappid,japikey);
        
        releaseMethod3(mi);
    }
    else{
        log("jni:initMintegralSDK false");
    }
}

//addcallback
void MTGCommonBridge::addCallbackCommonAd(CommonResultEvent callback)
{
    onCommonCallBack = callback;
}

//show
/*
void MTGCommonBridge::showUserPrivateInfoTips()
{
    cocos2d::JniMethodInfo mi;
    if (cocos2d::JniHelper::getStaticMethodInfo(mi, AppActivityCalssName3, "showUserPrivateInfoTips", "()V")) {
        
        mi.env->CallStaticVoidMethod(mi.classID, mi.methodID);
        
        releaseMethod3(mi);
    }else{
        log("jni:showUserPrivateInfoTips");
    }
}
*/
//set
void MTGCommonBridge::setUserPrivateInfoType(std::string statusKey,std::string statusType)
{
    cocos2d::JniMethodInfo mi;
    if (cocos2d::JniHelper::getStaticMethodInfo(mi, AppActivityCalssName3, "setUserPrivateInfoType", "(Ljava/lang/String;Ljava/lang/String;)V")) {
        
        jstring jstatusKey = mi.env->NewStringUTF( statusKey.c_str() );
        jstring jstatusType = mi.env->NewStringUTF( statusType.c_str() );
        
        mi.env->CallStaticVoidMethod(mi.classID, mi.methodID, jstatusKey, jstatusType);
        
        releaseMethod3(mi);
    }
    else{
        log("jni:setUserPrivateInfoType");
    }
}

//get

int MTGCommonBridge::userPrivateInfo(std::string statusKey)
{
    cocos2d::JniMethodInfo mi;
    if (cocos2d::JniHelper::getStaticMethodInfo(mi, AppActivityCalssName3, "userPrivateInfo", "(Ljava/lang/String;)I")) {
        
        jstring jstatusKey = mi.env->NewStringUTF( statusKey.c_str() );
        
        jint integer = mi.env->CallStaticIntMethod(mi.classID, mi.methodID, jstatusKey);
        releaseMethod3(mi);
        
        return integer;
    }else{
        log("jni:userPrivateInfo");
        return 0;
    }
}


/*
string MTGCommonBridge::userPrivateInfo(std::string statusKey)
{
    cocos2d::JniMethodInfo mi;
    if (cocos2d::JniHelper::getStaticMethodInfo(mi, AppActivityCalssName3, "userPrivateInfo", "(Ljava/lang/String;)C")) {
        
        jstring jstatusKey = mi.env->NewStringUTF( statusKey.c_str() );
        
        jchar tempStr = mi.env->CallStaticCharMethod(mi.classID, mi.methodID, jstatusKey);
        releaseMethod3(mi);
        
        return "1";
    }else{
        log("jni:userPrivateInfo");
        return "0";
    }
}
 */

void MTGCommonBridge::setConsentStatusInfoType(std::string statusType)
{
    cocos2d::JniMethodInfo mi;
    if (cocos2d::JniHelper::getStaticMethodInfo(mi, AppActivityCalssName3, "setConsentStatusInfoType", "(Ljava/lang/String;)V")) {
        
        jstring jstatusType = mi.env->NewStringUTF( statusType.c_str() );
        
        mi.env->CallStaticVoidMethod(mi.classID, mi.methodID, jstatusType);
        
        releaseMethod3(mi);
    }
    else{
        log("jni:setConsentStatusInfoType");
    }
}

bool MTGCommonBridge::getConsentStatusInfoType()
{
    cocos2d::JniMethodInfo mi;
    if (cocos2d::JniHelper::getStaticMethodInfo(mi, AppActivityCalssName3, "getConsentStatusInfoType", "()Z")) {
        
        jboolean bol = (jboolean)mi.env->CallStaticBooleanMethod(mi.classID, mi.methodID);
        releaseMethod3(mi);
        
        return bol;
    }else{
        log("jni:getConsentStatusInfoType false");
        return false;
    }
}


#elif (CC_TARGET_PLATFORM == CC_PLATFORM_IOS)

#include "MTGCommon.h"

void MTGCommonBridge::initMintegralSDK(string appid,string apikey)
{
    MTGCommon::initMintegralSDK(appid, apikey);
    return;
}
void MTGCommonBridge::addCallbackCommonAd(CommonResultEvent callback)
{
    MTGCommon::addCallbackCommonAd(callback);
    return;
}
/*
void MTGCommonBridge::showUserPrivateInfoTips()
{
    MTGCommon::showUserPrivateInfoTips();
    return;
}
 */
void MTGCommonBridge::setUserPrivateInfoType(string statusKey,string  statusType)
{
    MTGCommon::setUserPrivateInfoType(statusKey,statusType);
    return;
}
int MTGCommonBridge::userPrivateInfo(string statusKey)
{
    return MTGCommon::userPrivateInfo(statusKey); 
}

void MTGCommonBridge::setConsentStatusInfoType(string statusType)
{
    MTGCommon::setConsentStatusInfoType(statusType);
    return;
}

bool MTGCommonBridge::getConsentStatusInfoType()
{
    return MTGCommon::getConsentStatusInfoType();
}

#endif
