//
//  MTGAdInterstitialBridge.cpp
//  Cocos2dxSample-mobile
//
//  Created by YM on 2018/01/15.
//

#include "MTGAdInterActiveBridge.h"
#include "cocos2d.h"

USING_NS_CC;

using namespace cn::mtgsdk;

#if (CC_TARGET_PLATFORM == CC_PLATFORM_ANDROID)

#include "platform/android/jni/JniHelper.h"
#include <jni.h>

const char* AppActivityCalssName4 = "org/cocos2dx/mtgad/InterActive/MTGAdInterActive";

InterActiveResultEvent onInterActiveCallBack;

//JNI调用C++

extern "C" {

JNIEXPORT void JNICALL Java_org_cocos2dx_mtgad_InterActive_MTGAdInterActive_dispatchStatusEventAsync(JNIEnv *env, jclass, jstring jcode, jstring jlevel) {
    auto tempID = env->GetStringUTFChars(jcode, NULL);
    string codeID = tempID;
    env->ReleaseStringUTFChars(jcode, tempID);

    auto tempID1 = env->GetStringUTFChars(jlevel, NULL);
    string levelID = tempID1;
    env->ReleaseStringUTFChars(jlevel, tempID1);

    onInterActiveCallBack(codeID,levelID);
}
}

void releaseMethod4(JniMethodInfo &mi) {
    if(mi.classID != NULL)
        mi.env->DeleteLocalRef(mi.classID);
}

//initsdk
void MTGAdInterActiveBridge::initMintegralSDK(std::string appid,std::string apikey)
{
    cocos2d::JniMethodInfo mi;
    if (cocos2d::JniHelper::getStaticMethodInfo(mi, AppActivityCalssName4, "initMintegralSDK", "(Ljava/lang/String;Ljava/lang/String;)V")) {
        
        jstring jappid = mi.env->NewStringUTF( appid.c_str() );
        jstring japikey = mi.env->NewStringUTF( apikey.c_str() );
        
        mi.env->CallStaticVoidMethod(mi.classID, mi.methodID,jappid,japikey);
        
        releaseMethod4(mi);
    }
    else{
        log("jni:initMintegralSDK false");
    }
}

//addcallback
void MTGAdInterActiveBridge::addCallbackInterActiveAd(InterActiveResultEvent callback)
{
    onInterActiveCallBack = callback;
}

//load
void MTGAdInterActiveBridge::loadInterActiveAd(std::string unitid)
{
    cocos2d::JniMethodInfo mi;
    if (cocos2d::JniHelper::getStaticMethodInfo(mi, AppActivityCalssName4, "loadInterActiveAd", "(Ljava/lang/String;)V")) {
        
        jstring junitid = mi.env->NewStringUTF( unitid.c_str() );
        
        mi.env->CallStaticVoidMethod(mi.classID, mi.methodID,junitid);
        
        releaseMethod4(mi);
    }else{
        log("jni:loadInterActiveAd false");
    }
}

//show
void MTGAdInterActiveBridge::showInterActiveAd()
{
    cocos2d::JniMethodInfo mi;
    if (cocos2d::JniHelper::getStaticMethodInfo(mi, AppActivityCalssName4, "showInterActiveAd", "()V")) {
        
        mi.env->CallStaticVoidMethod(mi.classID, mi.methodID);
        
        releaseMethod4(mi);
    }
    else{
        log("jni:showInterActiveAd false");
    }
}

//get

int MTGAdInterActiveBridge::getInterActiveStatus()
{
    cocos2d::JniMethodInfo mi;
    if (cocos2d::JniHelper::getStaticMethodInfo(mi, AppActivityCalssName4, "getInterActiveStatus", "()I")) {
        
        jint integer = mi.env->CallStaticIntMethod(mi.classID, mi.methodID);
        releaseMethod4(mi);
        
        return integer;
    }else{
        log("jni:getInterActiveStatus");
        return 0;
    }
}

#elif (CC_TARGET_PLATFORM == CC_PLATFORM_IOS)

#include "MTGAdInterActive.h"

void MTGAdInterActiveBridge::initMintegralSDK(string appid,string apikey)
{
    MTGAdInterActive::initMintegralSDK(appid, apikey);
    return;
}
void MTGAdInterActiveBridge::addCallbackInterActiveAd(InterActiveResultEvent callback)
{
    MTGAdInterActive::addCallbackInterActiveAd(callback);
    return;
}
void MTGAdInterActiveBridge::loadInterActiveAd(string unitid)
{
    MTGAdInterActive::loadInterActiveAd(unitid);
    return;
}
void MTGAdInterActiveBridge::showInterActiveAd()
{
    MTGAdInterActive::showInterActiveAd();
    return;
}
int MTGAdInterActiveBridge::getInterActiveStatus()
{
    return MTGAdInterActive::getInterActiveStatus();
}

#endif
