//
//  MTGAdInterstitialBridge.cpp
//  Cocos2dxSample-mobile
//
//  Created by YM on 2018/01/15.
//

#include "MTGAdInterstitialBridge.h"
#include "cocos2d.h"

USING_NS_CC;

using namespace cn::mtgsdk;

#if (CC_TARGET_PLATFORM == CC_PLATFORM_ANDROID)

#include "platform/android/jni/JniHelper.h"
#include <jni.h>

const char* AppActivityCalssName2 = "org/cocos2dx/mtgad/Interstitial/MTGAdInterstitial";

InterstitialResultEvent onInterstitialCallBack;

//JNI调用C++

extern "C" {

JNIEXPORT void JNICALL Java_org_cocos2dx_mtgad_Interstitial_MTGAdInterstitial_dispatchStatusEventAsync(JNIEnv *env, jclass, jstring jcode, jstring jlevel) {
    auto tempID = env->GetStringUTFChars(jcode, NULL);
    string codeID = tempID;
    env->ReleaseStringUTFChars(jcode, tempID);

    auto tempID1 = env->GetStringUTFChars(jlevel, NULL);
    string levelID = tempID1;
    env->ReleaseStringUTFChars(jlevel, tempID1);

    onInterstitialCallBack(codeID,levelID);
}
}

void releaseMethod2(JniMethodInfo &mi) {
    if(mi.classID != NULL)
        mi.env->DeleteLocalRef(mi.classID);
}

//initsdk
void MTGAdInterstitialBridge::initMintegralSDK(std::string appid,std::string apikey)
{
    cocos2d::JniMethodInfo mi;
    if (cocos2d::JniHelper::getStaticMethodInfo(mi, AppActivityCalssName2, "initMintegralSDK", "(Ljava/lang/String;Ljava/lang/String;)V")) {
        
        jstring jappid = mi.env->NewStringUTF( appid.c_str() );
        jstring japikey = mi.env->NewStringUTF( apikey.c_str() );
        
        mi.env->CallStaticVoidMethod(mi.classID, mi.methodID,jappid,japikey);
        
        releaseMethod2(mi);
    }
    else{
        log("jni:initMintegralSDK false");
    }
}

//addcallback
void MTGAdInterstitialBridge::addCallbackInterstitialAd(InterstitialResultEvent callback)
{
    onInterstitialCallBack = callback;
}

//load
void MTGAdInterstitialBridge::loadInterstitialAd(std::string unitid)
{
    cocos2d::JniMethodInfo mi;
    if (cocos2d::JniHelper::getStaticMethodInfo(mi, AppActivityCalssName2, "loadInterstitialAd", "(Ljava/lang/String;)V")) {
        
        jstring junitid = mi.env->NewStringUTF( unitid.c_str() );
        
        mi.env->CallStaticVoidMethod(mi.classID, mi.methodID,junitid);
        
        releaseMethod2(mi);
    }else{
        log("jni:loadInterstitialAd false");
    }
}

//show
void MTGAdInterstitialBridge::showInterstitialAd()
{
    cocos2d::JniMethodInfo mi;
    if (cocos2d::JniHelper::getStaticMethodInfo(mi, AppActivityCalssName2, "showInterstitialAd", "()V")) {
        
        mi.env->CallStaticVoidMethod(mi.classID, mi.methodID);
        
        releaseMethod2(mi);
    }
    else{
        log("jni:showInterstitialAd false");
    }
}

#elif (CC_TARGET_PLATFORM == CC_PLATFORM_IOS)

#include "MTGAdInterstitial.h"

void MTGAdInterstitialBridge::initMintegralSDK(string appid,string apikey)
{
    MTGAdInterstitial::initMintegralSDK(appid, apikey);
    return;
}
void MTGAdInterstitialBridge::addCallbackInterstitialAd(InterstitialResultEvent callback)
{
    MTGAdInterstitial::addCallbackInterstitialAd(callback);
    return;
}
void MTGAdInterstitialBridge::loadInterstitialAd(string unitid)
{
    MTGAdInterstitial::loadInterstitialAd(unitid);
    return;
}
void MTGAdInterstitialBridge::showInterstitialAd()
{
    MTGAdInterstitial::showInterstitialAd();
    return;
}

#endif
