//
//  MTGAdRewardVideoBridge.cpp
//  Cocos2dxSample-mobile
//
//  Created by YM on 2017/12/19.
//

#include "MTGAdRewardVideoBridge.h"
#include "cocos2d.h"

USING_NS_CC;

using namespace cn::mtgsdk;

#if (CC_TARGET_PLATFORM == CC_PLATFORM_ANDROID)

#include "platform/android/jni/JniHelper.h"
#include <jni.h>

const char* AppActivityCalssName = "org/cocos2dx/mtgad/RewardVideo/MTGAdRewardVideo";

RewardVideoResultEvent onRewardVideoCallBack;

//JNI调用C++

extern "C" {

JNIEXPORT void JNICALL Java_org_cocos2dx_mtgad_RewardVideo_MTGAdRewardVideo_dispatchStatusEventAsync(JNIEnv *env, jclass, jstring jcode, jstring jlevel) {
    auto tempID = env->GetStringUTFChars(jcode, NULL);
    string codeID = tempID;
    env->ReleaseStringUTFChars(jcode, tempID);

    auto tempID1 = env->GetStringUTFChars(jlevel, NULL);
    string levelID = tempID1;
    env->ReleaseStringUTFChars(jlevel, tempID1);

    onRewardVideoCallBack(codeID,levelID);
}
}

void releaseMethod(JniMethodInfo &mi) {
    if(mi.classID != NULL)
        mi.env->DeleteLocalRef(mi.classID);
}

//initsdk
void MTGAdRewardVideoBridge::initMintegralSDK(std::string appid,std::string apikey)
{
    cocos2d::JniMethodInfo mi;
    if (cocos2d::JniHelper::getStaticMethodInfo(mi, AppActivityCalssName, "initMintegralSDK", "(Ljava/lang/String;Ljava/lang/String;)V")) {
        
        jstring jappid = mi.env->NewStringUTF( appid.c_str() );
        jstring japikey = mi.env->NewStringUTF( apikey.c_str() );
        
        mi.env->CallStaticVoidMethod(mi.classID, mi.methodID,jappid,japikey);
        
        releaseMethod(mi);
    }
    else{
        log("jni:initMintegralSDK false");
    }
}

//addcallback rv
void MTGAdRewardVideoBridge::addCallbackRewardVideoAd(RewardVideoResultEvent callback)
{
    onRewardVideoCallBack = callback;
}

//load rv
void MTGAdRewardVideoBridge::loadRewardVideoAd(std::string unitid)
{
    cocos2d::JniMethodInfo mi;
    if (cocos2d::JniHelper::getStaticMethodInfo(mi, AppActivityCalssName, "loadRewardVideoAd", "(Ljava/lang/String;)V")) {
        
        jstring junitid = mi.env->NewStringUTF( unitid.c_str() );
        
        mi.env->CallStaticVoidMethod(mi.classID, mi.methodID,junitid);
        
        releaseMethod(mi);
    }else{
        log("jni:loadRewardVideoAd false");
    }
}

//show rv
void MTGAdRewardVideoBridge::showRewardVideoAd(std::string unitid,std::string rewardid,std::string userid)
{
    cocos2d::JniMethodInfo mi;
    if (cocos2d::JniHelper::getStaticMethodInfo(mi, AppActivityCalssName, "showRewardVideoAd", "(Ljava/lang/String;Ljava/lang/String;Ljava/lang/String;)V")) {
        
        jstring junitid = mi.env->NewStringUTF( unitid.c_str() );
        jstring jrewardid = mi.env->NewStringUTF( rewardid.c_str() );
        jstring juserid = mi.env->NewStringUTF( userid.c_str() );
        
        mi.env->CallStaticVoidMethod(mi.classID, mi.methodID,junitid,jrewardid,juserid);
        
        releaseMethod(mi);
    }
    else{
        log("jni:showRewardVideoAd false");
    }
}
bool MTGAdRewardVideoBridge::isReadyRewardVideoAd(std::string unitid)
{
    cocos2d::JniMethodInfo mi;
    if (cocos2d::JniHelper::getStaticMethodInfo(mi, AppActivityCalssName, "isReadyRewardVideoAd", "()Z")) {

        jboolean bol = (jboolean)mi.env->CallStaticBooleanMethod(mi.classID, mi.methodID);
        releaseMethod(mi);

        return bol;
    }else{
        log("jni:isReadyRewardVideoAd false");
        return false;
    }
}
//cleanvideocache rv
void MTGAdRewardVideoBridge::cleanVideoCacheRewardVideoAd()
{
    cocos2d::JniMethodInfo mi;
    if (cocos2d::JniHelper::getStaticMethodInfo(mi, AppActivityCalssName, "cleanVideoCacheRewardVideoAd", "()V")) {
        
        mi.env->CallStaticVoidMethod(mi.classID, mi.methodID);
        
        releaseMethod(mi);
    }
    else{
        log("jni:cleanvideocacheRewardVideoAd false");
    }
}

#elif (CC_TARGET_PLATFORM == CC_PLATFORM_IOS)

#include "MTGAdRewardVideo.h"

void MTGAdRewardVideoBridge::initMintegralSDK(string appid,string apikey)
{
    MTGAdRewardVideo::initMintegralSDK(appid, apikey);
    return;
}
void MTGAdRewardVideoBridge::addCallbackRewardVideoAd(RewardVideoResultEvent callback)
{
    MTGAdRewardVideo::addCallbackRewardVideoAd(callback);
    return;
}
void MTGAdRewardVideoBridge::loadRewardVideoAd(string unitid)
{
    MTGAdRewardVideo::loadRewardVideoAd(unitid);
    return;
}
void MTGAdRewardVideoBridge::showRewardVideoAd(string unitid,string rewardid,string userid)
{
    MTGAdRewardVideo::showRewardVideoAd(unitid,rewardid,userid);
    return;
}
bool MTGAdRewardVideoBridge::isReadyRewardVideoAd(string unitid)
{
    return MTGAdRewardVideo::isReadyRewardVideoAd(unitid);
}
void MTGAdRewardVideoBridge::cleanVideoCacheRewardVideoAd()
{
    MTGAdRewardVideo::cleanVideoCacheRewardVideoAd();
    return;
}

#endif
