package org.cocos2dx.mtgad.Interstitial;

import android.text.TextUtils;
import android.util.Log;

import java.util.Map;
import java.util.HashMap;
import java.util.concurrent.Callable;
import java.util.concurrent.FutureTask;

import org.cocos2dx.lib.Cocos2dxHelper;
import org.cocos2dx.mtgad.MTGAdUtility;

import com.mintegral.msdk.MIntegralSDK;
import com.mintegral.msdk.MIntegralConstans;
import com.mintegral.msdk.out.MIntegralSDKFactory;
import com.mintegral.msdk.out.MTGInterstitialHandler;
import com.mintegral.msdk.out.InterstitialListener;

public class MTGAdInterstitial{

    private static MTGInterstitialHandler mtgInterstitialHandler;

    //init Mintegral
    public static void initMTGSdk(final String appid,final String apikey){
        if(!MTGAdUtility.isSDKInitialized()) {

            //init sdk
            MIntegralSDK sdk = MIntegralSDKFactory.getMIntegralSDK();
            Map<String, String> map = sdk.getMTGConfigurationMap(appid, apikey);
            if (!TextUtils.isEmpty("")) {
                map.put("applicationID", "");
            }
            sdk.init(map, Cocos2dxHelper.getActivity());
            MTGAdUtility.sdkInitialized();
        }
    }

    //init interstitial
    public static void initInterstitialHander(final String unitid){
        HashMap<String, Object> hashMap = new HashMap<String, Object>();
        hashMap.put(MIntegralConstans.PROPERTIES_UNIT_ID, unitid);
        mtgInterstitialHandler = new MTGInterstitialHandler(Cocos2dxHelper.getActivity(), hashMap);

        mtgInterstitialHandler
                .setInterstitialListener(new InterstitialListener() {
                    @Override
                    public void onInterstitialShowSuccess() {
                        dispatchStatusEventAsync("onAdShowInterstitial","onAdShow");
                    }

                    @Override
                    public void onInterstitialShowFail(String errorMsg) {
                        dispatchStatusEventAsync("onShowFailInterstitial",errorMsg);
                    }

                    @Override
                    public void onInterstitialLoadSuccess() {
                        dispatchStatusEventAsync("onLoadSuccessInterstitial","onLoadSuccess");
                    }

                    @Override
                    public void onInterstitialLoadFail(String errorMsg) {
                        dispatchStatusEventAsync("onLoadFailInterstitial",errorMsg);
                    }

                    @Override
                    public void onInterstitialClosed() {
                        dispatchStatusEventAsync("onAdCloseInterstitial","onAdClose");
                    }

                    @Override
                    public void onInterstitialAdClick() {
                        dispatchStatusEventAsync("onAdClickedInterstitial","onAdClicked");
                    }
                });
    }

    //load interstitial
    public static void interstitialLoad(){
        if (mtgInterstitialHandler != null) {
            mtgInterstitialHandler.preload();
        }else{
            Log.e("error load","please init");
        }
    }

    //show interstitial
    public static void interstitialShow(){
        if (mtgInterstitialHandler != null) {
            mtgInterstitialHandler.show();
        }else{
            Log.e("error show","please load");
        }
    }


    public static void initMintegralSDK(final String appid,final String apikey) {

        FutureTask<String> task = new FutureTask<String>(new Callable<String>() {
            @Override
            public String call() throws Exception {

                initMTGSdk(appid,apikey);

                return "";
            }
        });

        try {
            Cocos2dxHelper.getActivity().runOnUiThread(task);
        } catch (Exception e) {}
    }
    public static void loadInterstitialAd(final String unitid) {

        FutureTask<String> task = new FutureTask<String>(new Callable<String>() {
            @Override
            public String call() throws Exception {

                if(mtgInterstitialHandler != null){
                    mtgInterstitialHandler = null;
                }
                initInterstitialHander(unitid);
                interstitialLoad();

                return "";
            }
        });
        try {
            Cocos2dxHelper.getActivity().runOnUiThread(task);
        } catch (Exception e) {}
    }
    public static void showInterstitialAd() {

        FutureTask<String> task = new FutureTask<String>(new Callable<String>() {
            @Override
            public String call() throws Exception {

                interstitialShow();

                return "";
            }
        });

        try {
            Cocos2dxHelper.getActivity().runOnUiThread(task);
        } catch (Exception e) {}
    }
    //callBack
    private static native void dispatchStatusEventAsync(String code,String level);

}
