package org.cocos2dx.mtgad.RewardVideo;

import android.text.TextUtils;
import android.util.Log;

import java.util.Map;
import java.util.concurrent.Callable;
import java.util.concurrent.FutureTask;

import org.cocos2dx.lib.Cocos2dxHelper;
import org.cocos2dx.mtgad.MTGAdUtility;
import org.json.JSONException;
import org.json.JSONObject;

import com.mintegral.msdk.out.MTGRewardVideoHandler;
import com.mintegral.msdk.out.RewardVideoListener;

import com.mintegral.msdk.MIntegralSDK;
import com.mintegral.msdk.MIntegralConstans;
import com.mintegral.msdk.out.MIntegralSDKFactory;

public class MTGAdRewardVideo{

    private static MTGRewardVideoHandler mtgRewardVideoHandler;

    //init Mintegral
    public static void initMTGSdk(final String appid,final String apikey){
        if(!MTGAdUtility.isSDKInitialized()) {

            //init sdk
            MIntegralSDK sdk = MIntegralSDKFactory.getMIntegralSDK();
            Map<String, String> map = sdk.getMTGConfigurationMap(appid, apikey);
            if (!TextUtils.isEmpty("")) {
                map.put("applicationID", "");
            }
            sdk.init(map, Cocos2dxHelper.getActivity());
            MTGAdUtility.sdkInitialized();
        }
    }

    //init RewardVideo
    public static void initRewardVideoHander(final String unitid){
        mtgRewardVideoHandler = new MTGRewardVideoHandler(Cocos2dxHelper.getActivity(), unitid);
        mtgRewardVideoHandler
                .setRewardVideoListener(new RewardVideoListener() {

                    public void onLoadSuccess(String unitId) {
                        dispatchStatusEventAsync("onAdLoadSuccess",unitId);
                    }

                    public void onVideoLoadSuccess(String unitId) {
                        dispatchStatusEventAsync("onLoadSuccessRewardVideo",unitId);
                    }

                    public void onVideoLoadFail(String unitId) {
                        dispatchStatusEventAsync("onLoadFailRewardVideo",unitId);
                    }

                    public void onShowFail(String errorMsg) {
                        dispatchStatusEventAsync("onShowFailRewardVideo",errorMsg);
                    }

                    public void onAdShow() {
                        dispatchStatusEventAsync("onAdShowRewardVideo","onAdShowRewardVideo");
                    }

                    public void onAdClose(boolean isCompleteView,
                                          String RewardName, float RewardAmout) {
                        if (isCompleteView) {
                            JSONObject jsonObjectReward = new JSONObject();
                            try {
                                jsonObjectReward.put("rewardName",
                                        RewardName);
                                jsonObjectReward.put("rewardAmount",
                                        RewardAmout + "");
                            } catch (JSONException e) {
                                e.printStackTrace();
                            }
                            dispatchStatusEventAsync("onAdCloseRewardVideo",
                                            jsonObjectReward.toString());
                        } else {
                            dispatchStatusEventAsync("onAdCloseRewardVideo",
                                            "failComplete");
                        }
                    }

                    public void onVideoAdClicked(String unitId) {
                        dispatchStatusEventAsync("onAdClickedRewardVideo",unitId);
                    }
                });
    }

    //load rv
    public static void rewardVideoLoad(){
        if (mtgRewardVideoHandler != null) {
            mtgRewardVideoHandler.load();
        }else{
            Log.e("error load","please init");
        }
    }

    //show rv
    public static void rewardVideoShow(final String rewardid,final String userid){
        if (mtgRewardVideoHandler != null) {
            mtgRewardVideoHandler.show(rewardid, userid);
        }else{
            Log.e("error show","please load");
        }
    }

    //isready rv
    public static boolean rewardVideoIsready(){
        if (mtgRewardVideoHandler != null) {
            return mtgRewardVideoHandler.isReady();
        } else {
            return false;
        }
    }
    //cleanvideocache
    public static void rewardVideocleanVideoCache(){
        if (mtgRewardVideoHandler != null) {
            mtgRewardVideoHandler.clearVideoCache();
        }
    }



    public static void initMintegralSDK(final String appid,final String apikey) {

        FutureTask<String> task = new FutureTask<String>(new Callable<String>() {
            @Override
            public String call() throws Exception {

                initMTGSdk(appid,apikey);

                return "";
            }
        });

        try {
            Cocos2dxHelper.getActivity().runOnUiThread(task);
        } catch (Exception e) {}
    }
    public static void loadRewardVideoAd(final String unitid) {

        FutureTask<String> task = new FutureTask<String>(new Callable<String>() {
            @Override
            public String call() throws Exception {

                if(mtgRewardVideoHandler != null){
                    mtgRewardVideoHandler = null;
                }
                initRewardVideoHander(unitid);
                rewardVideoLoad();

                return "";
            }
        });
        try {
            Cocos2dxHelper.getActivity().runOnUiThread(task);
        } catch (Exception e) {}
    }
    public static void showRewardVideoAd(final String unitid,final String rewardid,final String userid) {

        FutureTask<String> task = new FutureTask<String>(new Callable<String>() {
            @Override
            public String call() throws Exception {

                rewardVideoShow(rewardid,userid);

                return "";
            }
        });

        try {
            Cocos2dxHelper.getActivity().runOnUiThread(task);
        } catch (Exception e) {}
    }
    public static boolean isReadyRewardVideoAd() {

        FutureTask<Boolean> task = new FutureTask<Boolean>(new Callable<Boolean>() {
            @Override
            public Boolean call() throws Exception {

                return rewardVideoIsready();
            }
        });

        try {
            Cocos2dxHelper.getActivity().runOnUiThread(task);
            Boolean bol = task.get();
            return bol;
        } catch (Exception e) {return false;}
    }
    public static void cleanVideoCacheRewardVideoAd() {

        FutureTask<String> task = new FutureTask<String>(new Callable<String>() {
            @Override
            public String call() throws Exception {

                rewardVideocleanVideoCache();
                return "";
            }
        });

        try {
            Cocos2dxHelper.getActivity().runOnUiThread(task);
        } catch (Exception e) {}
    }
    //callBack
    private static native void dispatchStatusEventAsync(String code,String level);

}
